pub fn detect_format(path: &Path) -> Option<DocumentFormat>Expand description
Detects the document format from file extension and magic bytes.
pub fn detect_format(path: &Path) -> Option<DocumentFormat>Detects the document format from file extension and magic bytes.