Module security

Module security 

Security guards for SSRF protection and ZIP bomb / element explosion prevention.

Mirrors the protection offered by OfficeCLI’s SsrfGuard and GuardDecompressionBomb / GuardElementExplosion.

These guards should be called at the reader entry point (from_path / from_reader) and before ZIP content extraction.

Structs

PackageLimits
ZIP archive size and complexity limits to prevent decompression bombs and element explosion attacks.
SecurityPolicy
Combined security policy holding SSRF and ZIP limits guards.
SsrfGuard
SSRF (Server-Side Request Forgery) protection configuration.