render_view

Function render_view 

pub fn render_view(content: &DocumentContent, mode: &ViewMode) -> Result<String>
Renders a DocumentContent into a string according to the chosen ViewMode.

Errors

Returns an error if rendering fails (currently infallible, but the signature allows for future fallible rendering).